==> resin-4.0.32-src.tar.gz: resin-4.0.32/modules/jcache/src/javax/cache/CacheManager.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.cache;

import javax.transaction.UserTransaction;

public interface CacheManager
{
  public String getName();
  
  public Status getStatus();
  
  public <K,V> CacheBuilder<K,V> createCacheBuilder(String cacheName);
  
  public <K,V> Cache<K,V> getCache(String name);
  
  public <K,V> Iterable<Cache<K,V>> getCaches();
  
  public boolean removeCache(String cacheName);
  
  public UserTransaction getUserTransaction();
  
  public boolean isSupported(OptionalFeature optionalFeature);
  
  public void shutdown();
  
  public <T> T unwrap(Class<T> cl);
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/jcache/src/javax/cache/CacheManager.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.cache;

import javax.transaction.UserTransaction;

public interface CacheManager
{
  String getName();
  
  Status getStatus();
  
  <K,V> Cache<K,V> configureCache(String cacheName,
                                  Configuration<K,V> configuration);
  
  <K,V> Cache<K,V> getCache(String name);
  
  Iterable<Cache<?,?>> getCaches();
  
  boolean removeCache(String cacheName);
  
  UserTransaction getUserTransaction();
  
  boolean isSupported(OptionalFeature optionalFeature);
  
  void enableStatistics(String cacheName, boolean enabled);
  
  void shutdown();
  
  <T> T unwrap(Class<T> cl);
}
